@@ -1,3 +1,16 @@
+"""
+Copyright 2020 Qiniu Cloud (qiniu.com)
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+ http://www.apache.org/licenses/LICENSE-2.0
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+"""
+
 import urllib3
 import json
 import time
@@ -68,10 +81,14 @@ class PandoraConnection(object):
         """
         self.scheme = kwargs.get("scheme", DEFAULT_SCHEME)
         self.host = kwargs.get("host", DEFAULT_HOST)
-        self.port = int(kwargs.get("port", DEFAULT_PORT))
+        self.port = kwargs.get("port", None)
         self.root_path = kwargs.get("root_path", API_ROOT_PREFIX)
-        self.root_url = urllib3.util.Url(
-            host=self.host, scheme=self.scheme, port=self.port, path=self.root_path)
+        if not self.port:
+            self.root_url = urllib3.util.Url(
+                host=self.host, scheme=self.scheme, path=self.root_path)
+        else:
+            self.root_url = urllib3.util.Url(
+                host=self.host, scheme=self.scheme, port=self.port, path=self.root_path)
 
         self.token = kwargs.get("token", "")
         self.session_key = kwargs.get("session_key", "")
@@ -194,7 +211,6 @@ class PandoraConnection(object):
         """
         kwargs["mode"] = "fast"
         kwargs["preview"] = False
-        kwargs["collectSize"] = -1
         return self.create_query_job(spl, **kwargs)
 
     def create_query_job(self, spl, **kwargs):
